@@ -2020,6 +2020,10 @@ class PivotTableAutoFormatType(IntEnum):
     TABLE_7 = 18,
     TABLE_8 = 19,
     TABLE_9 = 20,
+class PivotTableSelectionType(IntEnum):
+    DATA_AND_LABEL = 0,
+    DATA_ONLY = 2,
+    LABEL_ONLY = 1,
 class PivotTableStyleType(IntEnum):
     CUSTOM = 85,
     NONE = 0,
@@ -2557,7 +2561,7 @@ class SqlScriptOperatorType(IntEnum):
     UPDATE = 1,
 class StyleModifyFlag(IntEnum):
     ALIGNMENT_SETTINGS = 4161664,
-    ALL = 234881011,
+    ALL = 234881012,
     BACKGROUND_COLOR = 16777216,
     BORDERS = 16224,
     BOTTOM_BORDER = 2048,
@@ -2565,7 +2569,7 @@ class StyleModifyFlag(IntEnum):
     DIAGONAL = 12288,
     DIAGONAL_DOWN_BORDER = 4096,
     DIAGONAL_UP_BORDER = 8192,
-    FONT = 19,
+    FONT = 20,
     FONT_CAP = 18,
     FONT_CHARSET = 10,
     FONT_COLOR = 3,
@@ -2583,6 +2587,7 @@ class StyleModifyFlag(IntEnum):
     FONT_STRIKE = 7,
     FONT_U_FILL_TX = 14,
     FONT_UNDERLINE = 6,
+    FONT_VERTICAL_TEXT = 19,
     FONT_WEIGHT = 4,
     FOREGROUND_COLOR = 8388608,
     HIDE_FORMULA = 134217728,
@@ -3029,6 +3034,7 @@ from com.aspose.cells import PdfSaveOptions
 from com.aspose.cells import PdfSecurityOptions
 from com.aspose.cells import PicFormatOption
 from com.aspose.cells import PictureBulletValue
+from com.aspose.cells import PivotArea
 from com.aspose.cells import PivotGlobalizationSettings
 from com.aspose.cells import PivotPageFields
 from com.aspose.cells import PowerQueryFormulaParameter
